window.Gleam.initSearch([{"doc":"klubok_gleam","title":"klubok_gleam","content":"# klubok_gleam\n\n[![Package Version](https://img.shields.io/hexpm/v/klubok_gleam)](https://hex.pm/packages/klubok_gleam)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/klubok_gleam/)\n![Erlang-compatible](https://img.shields.io/badge/target-erlang-a2003e)\n![JavaScript-compatible](https://img.shields.io/badge/target-javascript-f1e05a)\n\n![logo](https://raw.githubusercontent.com/darky/klubok/refs/heads/main/logo.png)\n\nDo notation pipes for functions which easy to mock &lt;br/&gt;\nInspired by fp-ts/Effect bind Do-notation, but much more small and simple &lt;br/&gt;\nPrimarly created for easy mocking of functions, which allows to write tons of unit tests\n\n```sh\ngleam add klubok_gleam\n```\n\n```gleam\nimport gleam/option.{None, Some}\nimport gleam/set\nimport klubok_gleam.{use_klubok2, eff}\n\ntype Cat {\n  Cat(name: String, age: Int)\n}\n\nfn cat_birthday(mock, only) {\n  // Make this function pipable\n  // Need to use correct arity by count of `eff` usage, 2 in this example\n  use &lt;- use_klubok2(mock, only)\n\n  // This function mockable\n  use cat &lt;- eff(fn() {\n    // some IO implementation which fetching cat\n    Cat(&quot;Barsik&quot;, 5)\n  })\n\n  // This function mockable\n  use aged_cat &lt;- eff(fn() { Cat(..cat, age: cat.age + 1) })\n\n  aged_cat\n}\n\npub fn main() {\n  // Pass Option.None to mock and only\n  // Should be used on production code\n  cat_birthday(None, None) // Cat(&quot;Barsik&quot;, 6)\n\n  // Mock first `eff` with another hardcoded cat\n  // Should be used in unit tests\n  cat_birthday(#(fn() { Cat(&quot;Marfa&quot;, 10) } |&gt; Some, None) |&gt; Some, None) // Cat(&quot;Marfa&quot;, 11)\n\n  // Call only second `eff` and first IO ignored\n  // Also our birthday fn is mocked and our cat is kiten again\n  //❗`only` is type unsafe and can lead to runtime errors when `Nil` passed instead of actual `eff` value\n  cat_birthday(\n    #(None, fn() { Cat(&quot;Barsik&quot;, 1) } |&gt; Some) |&gt; Some,\n    set.from_list([1]) |&gt; Some\n  ) // Cat(&quot;Barsik&quot;, 1)\n}\n```\n\nFurther documentation can be found at &lt;https://hexdocs.pm/klubok_gleam&gt;.\n\n## Development\n\n```sh\ngleam run   # Run the project\ngleam test  # Run the tests\n```\n\n## See also\n\n* [Klubok](https://github.com/darky/klubok) - TS implementation of Klubok\n","url":"index.html"},{"doc":"klubok_gleam","title":"Step","content":"pub type Step(action, next) {\n  Step(action: action, next: next)\n}\n\nStep(action: action, next: next)\n\n\nSynonyms:\nklubok_gleam.Step\nklubok_gleam Step","url":"klubok_gleam.html#Step"},{"doc":"klubok_gleam","title":"eff","content":"pub fn eff(action: a, cb: b) -&gt; Step(a, b)\n\nSynonyms:\nklubok_gleam.eff\nklubok_gleam eff","url":"klubok_gleam.html#eff"},{"doc":"klubok_gleam","title":"use_klubok1","content":"pub fn use_klubok1(\n  mock: Option(#(Option(fn() -&gt; a))),\n  only: Option(Set(Int)),\n  init: fn() -&gt; Step(fn() -&gt; a, fn(a) -&gt; b),\n) -&gt; b\n\nSynonyms:\nklubok_gleam.use_klubok1\nklubok_gleam use_klubok1","url":"klubok_gleam.html#use_klubok1"},{"doc":"klubok_gleam","title":"use_klubok10","content":"pub fn use_klubok10(\n  mock: Option(\n    #(\n      Option(fn() -&gt; a),\n      Option(fn() -&gt; b),\n      Option(fn() -&gt; c),\n      Option(fn() -&gt; d),\n      Option(fn() -&gt; e),\n      Option(fn() -&gt; f),\n      Option(fn() -&gt; g),\n      Option(fn() -&gt; h),\n      Option(fn() -&gt; i),\n      Option(fn() -&gt; j),\n    ),\n  ),\n  only: Option(Set(Int)),\n  init: fn() -&gt;\n    Step(\n      fn() -&gt; a,\n      fn(a) -&gt;\n        Step(\n          fn() -&gt; b,\n          fn(b) -&gt;\n            Step(\n              fn() -&gt; c,\n              fn(c) -&gt;\n                Step(\n                  fn() -&gt; d,\n                  fn(d) -&gt;\n                    Step(\n                      fn() -&gt; e,\n                      fn(e) -&gt;\n                        Step(\n                          fn() -&gt; f,\n                          fn(f) -&gt;\n                            Step(\n                              fn() -&gt; g,\n                              fn(g) -&gt;\n                                Step(\n                                  fn() -&gt; h,\n                                  fn(h) -&gt;\n                                    Step(\n                                      fn() -&gt; i,\n                                      fn(i) -&gt;\n                                        Step(\n                                          fn() -&gt; j,\n                                          fn(j) -&gt; k,\n                                        ),\n                                    ),\n                                ),\n                            ),\n                        ),\n                    ),\n                ),\n            ),\n        ),\n    ),\n) -&gt; k\n\nSynonyms:\nklubok_gleam.use_klubok10\nklubok_gleam use_klubok10","url":"klubok_gleam.html#use_klubok10"},{"doc":"klubok_gleam","title":"use_klubok11","content":"pub fn use_klubok11(\n  mock: Option(\n    #(\n      Option(fn() -&gt; a),\n      Option(fn() -&gt; b),\n      Option(fn() -&gt; c),\n      Option(fn() -&gt; d),\n      Option(fn() -&gt; e),\n      Option(fn() -&gt; f),\n      Option(fn() -&gt; g),\n      Option(fn() -&gt; h),\n      Option(fn() -&gt; i),\n      Option(fn() -&gt; j),\n      Option(fn() -&gt; k),\n    ),\n  ),\n  only: Option(Set(Int)),\n  init: fn() -&gt;\n    Step(\n      fn() -&gt; a,\n      fn(a) -&gt;\n        Step(\n          fn() -&gt; b,\n          fn(b) -&gt;\n            Step(\n              fn() -&gt; c,\n              fn(c) -&gt;\n                Step(\n                  fn() -&gt; d,\n                  fn(d) -&gt;\n                    Step(\n                      fn() -&gt; e,\n                      fn(e) -&gt;\n                        Step(\n                          fn() -&gt; f,\n                          fn(f) -&gt;\n                            Step(\n                              fn() -&gt; g,\n                              fn(g) -&gt;\n                                Step(\n                                  fn() -&gt; h,\n                                  fn(h) -&gt;\n                                    Step(\n                                      fn() -&gt; i,\n                                      fn(i) -&gt;\n                                        Step(\n                                          fn() -&gt; j,\n                                          fn(j) -&gt;\n                                            Step(\n                                              fn() -&gt; k,\n                                              fn(k) -&gt; l,\n                                            ),\n                                        ),\n                                    ),\n                                ),\n                            ),\n                        ),\n                    ),\n                ),\n            ),\n        ),\n    ),\n) -&gt; l\n\nSynonyms:\nklubok_gleam.use_klubok11\nklubok_gleam use_klubok11","url":"klubok_gleam.html#use_klubok11"},{"doc":"klubok_gleam","title":"use_klubok12","content":"pub fn use_klubok12(\n  mock: Option(\n    #(\n      Option(fn() -&gt; a),\n      Option(fn() -&gt; b),\n      Option(fn() -&gt; c),\n      Option(fn() -&gt; d),\n      Option(fn() -&gt; e),\n      Option(fn() -&gt; f),\n      Option(fn() -&gt; g),\n      Option(fn() -&gt; h),\n      Option(fn() -&gt; i),\n      Option(fn() -&gt; j),\n      Option(fn() -&gt; k),\n      Option(fn() -&gt; l),\n    ),\n  ),\n  only: Option(Set(Int)),\n  init: fn() -&gt;\n    Step(\n      fn() -&gt; a,\n      fn(a) -&gt;\n        Step(\n          fn() -&gt; b,\n          fn(b) -&gt;\n            Step(\n              fn() -&gt; c,\n              fn(c) -&gt;\n                Step(\n                  fn() -&gt; d,\n                  fn(d) -&gt;\n                    Step(\n                      fn() -&gt; e,\n                      fn(e) -&gt;\n                        Step(\n                          fn() -&gt; f,\n                          fn(f) -&gt;\n                            Step(\n                              fn() -&gt; g,\n                              fn(g) -&gt;\n                                Step(\n                                  fn() -&gt; h,\n                                  fn(h) -&gt;\n                                    Step(\n                                      fn() -&gt; i,\n                                      fn(i) -&gt;\n                                        Step(\n                                          fn() -&gt; j,\n                                          fn(j) -&gt;\n                                            Step(\n                                              fn() -&gt; k,\n                                              fn(k) -&gt;\n                                                Step(\n                                                  fn() -&gt; l,\n                                                  fn(l) -&gt; m,\n                                                ),\n                                            ),\n                                        ),\n                                    ),\n                                ),\n                            ),\n                        ),\n                    ),\n                ),\n            ),\n        ),\n    ),\n) -&gt; m\n\nSynonyms:\nklubok_gleam.use_klubok12\nklubok_gleam use_klubok12","url":"klubok_gleam.html#use_klubok12"},{"doc":"klubok_gleam","title":"use_klubok13","content":"pub fn use_klubok13(\n  mock: Option(\n    #(\n      Option(fn() -&gt; a),\n      Option(fn() -&gt; b),\n      Option(fn() -&gt; c),\n      Option(fn() -&gt; d),\n      Option(fn() -&gt; e),\n      Option(fn() -&gt; f),\n      Option(fn() -&gt; g),\n      Option(fn() -&gt; h),\n      Option(fn() -&gt; i),\n      Option(fn() -&gt; j),\n      Option(fn() -&gt; k),\n      Option(fn() -&gt; l),\n      Option(fn() -&gt; m),\n    ),\n  ),\n  only: Option(Set(Int)),\n  init: fn() -&gt;\n    Step(\n      fn() -&gt; a,\n      fn(a) -&gt;\n        Step(\n          fn() -&gt; b,\n          fn(b) -&gt;\n            Step(\n              fn() -&gt; c,\n              fn(c) -&gt;\n                Step(\n                  fn() -&gt; d,\n                  fn(d) -&gt;\n                    Step(\n                      fn() -&gt; e,\n                      fn(e) -&gt;\n                        Step(\n                          fn() -&gt; f,\n                          fn(f) -&gt;\n                            Step(\n                              fn() -&gt; g,\n                              fn(g) -&gt;\n                                Step(\n                                  fn() -&gt; h,\n                                  fn(h) -&gt;\n                                    Step(\n                                      fn() -&gt; i,\n                                      fn(i) -&gt;\n                                        Step(\n                                          fn() -&gt; j,\n                                          fn(j) -&gt;\n                                            Step(\n                                              fn() -&gt; k,\n                                              fn(k) -&gt;\n                                                Step(\n                                                  fn() -&gt; l,\n                                                  fn(l) -&gt;\n                                                    Step(\n                                                      fn() -&gt; m,\n                                                      fn(m) -&gt; n,\n                                                    ),\n                                                ),\n                                            ),\n                                        ),\n                                    ),\n                                ),\n                            ),\n                        ),\n                    ),\n                ),\n            ),\n        ),\n    ),\n) -&gt; n\n\nSynonyms:\nklubok_gleam.use_klubok13\nklubok_gleam use_klubok13","url":"klubok_gleam.html#use_klubok13"},{"doc":"klubok_gleam","title":"use_klubok14","content":"pub fn use_klubok14(\n  mock: Option(\n    #(\n      Option(fn() -&gt; a),\n      Option(fn() -&gt; b),\n      Option(fn() -&gt; c),\n      Option(fn() -&gt; d),\n      Option(fn() -&gt; e),\n      Option(fn() -&gt; f),\n      Option(fn() -&gt; g),\n      Option(fn() -&gt; h),\n      Option(fn() -&gt; i),\n      Option(fn() -&gt; j),\n      Option(fn() -&gt; k),\n      Option(fn() -&gt; l),\n      Option(fn() -&gt; m),\n      Option(fn() -&gt; n),\n    ),\n  ),\n  only: Option(Set(Int)),\n  init: fn() -&gt;\n    Step(\n      fn() -&gt; a,\n      fn(a) -&gt;\n        Step(\n          fn() -&gt; b,\n          fn(b) -&gt;\n            Step(\n              fn() -&gt; c,\n              fn(c) -&gt;\n                Step(\n                  fn() -&gt; d,\n                  fn(d) -&gt;\n                    Step(\n                      fn() -&gt; e,\n                      fn(e) -&gt;\n                        Step(\n                          fn() -&gt; f,\n                          fn(f) -&gt;\n                            Step(\n                              fn() -&gt; g,\n                              fn(g) -&gt;\n                                Step(\n                                  fn() -&gt; h,\n                                  fn(h) -&gt;\n                                    Step(\n                                      fn() -&gt; i,\n                                      fn(i) -&gt;\n                                        Step(\n                                          fn() -&gt; j,\n                                          fn(j) -&gt;\n                                            Step(\n                                              fn() -&gt; k,\n                                              fn(k) -&gt;\n                                                Step(\n                                                  fn() -&gt; l,\n                                                  fn(l) -&gt;\n                                                    Step(\n                                                      fn() -&gt; m,\n                                                      fn(m) -&gt;\n                                                        Step(\n                                                          fn() -&gt;\n                                                            n,\n                                                          fn(n) -&gt;\n                                                            o,\n                                                        ),\n                                                    ),\n                                                ),\n                                            ),\n                                        ),\n                                    ),\n                                ),\n                            ),\n                        ),\n                    ),\n                ),\n            ),\n        ),\n    ),\n) -&gt; o\n\nSynonyms:\nklubok_gleam.use_klubok14\nklubok_gleam use_klubok14","url":"klubok_gleam.html#use_klubok14"},{"doc":"klubok_gleam","title":"use_klubok15","content":"pub fn use_klubok15(\n  mock: Option(\n    #(\n      Option(fn() -&gt; a),\n      Option(fn() -&gt; b),\n      Option(fn() -&gt; c),\n      Option(fn() -&gt; d),\n      Option(fn() -&gt; e),\n      Option(fn() -&gt; f),\n      Option(fn() -&gt; g),\n      Option(fn() -&gt; h),\n      Option(fn() -&gt; i),\n      Option(fn() -&gt; j),\n      Option(fn() -&gt; k),\n      Option(fn() -&gt; l),\n      Option(fn() -&gt; m),\n      Option(fn() -&gt; n),\n      Option(fn() -&gt; o),\n    ),\n  ),\n  only: Option(Set(Int)),\n  init: fn() -&gt;\n    Step(\n      fn() -&gt; a,\n      fn(a) -&gt;\n        Step(\n          fn() -&gt; b,\n          fn(b) -&gt;\n            Step(\n              fn() -&gt; c,\n              fn(c) -&gt;\n                Step(\n                  fn() -&gt; d,\n                  fn(d) -&gt;\n                    Step(\n                      fn() -&gt; e,\n                      fn(e) -&gt;\n                        Step(\n                          fn() -&gt; f,\n                          fn(f) -&gt;\n                            Step(\n                              fn() -&gt; g,\n                              fn(g) -&gt;\n                                Step(\n                                  fn() -&gt; h,\n                                  fn(h) -&gt;\n                                    Step(\n                                      fn() -&gt; i,\n                                      fn(i) -&gt;\n                                        Step(\n                                          fn() -&gt; j,\n                                          fn(j) -&gt;\n                                            Step(\n                                              fn() -&gt; k,\n                                              fn(k) -&gt;\n                                                Step(\n                                                  fn() -&gt; l,\n                                                  fn(l) -&gt;\n                                                    Step(\n                                                      fn() -&gt; m,\n                                                      fn(m) -&gt;\n                                                        Step(\n                                                          fn() -&gt;\n                                                            n,\n                                                          fn(n) -&gt;\n                                                            Step(\n                                                              fn() -&gt;\n                                                                o,\n                                                              fn(\n                                                                o,\n                                                              ) -&gt;\n                                                                p,\n                                                            ),\n                                                        ),\n                                                    ),\n                                                ),\n                                            ),\n                                        ),\n                                    ),\n                                ),\n                            ),\n                        ),\n                    ),\n                ),\n            ),\n        ),\n    ),\n) -&gt; p\n\nSynonyms:\nklubok_gleam.use_klubok15\nklubok_gleam use_klubok15","url":"klubok_gleam.html#use_klubok15"},{"doc":"klubok_gleam","title":"use_klubok2","content":"pub fn use_klubok2(\n  mock: Option(#(Option(fn() -&gt; a), Option(fn() -&gt; b))),\n  only: Option(Set(Int)),\n  init: fn() -&gt;\n    Step(fn() -&gt; a, fn(a) -&gt; Step(fn() -&gt; b, fn(b) -&gt; c)),\n) -&gt; c\n\nSynonyms:\nklubok_gleam.use_klubok2\nklubok_gleam use_klubok2","url":"klubok_gleam.html#use_klubok2"},{"doc":"klubok_gleam","title":"use_klubok3","content":"pub fn use_klubok3(\n  mock: Option(\n    #(Option(fn() -&gt; a), Option(fn() -&gt; b), Option(fn() -&gt; c)),\n  ),\n  only: Option(Set(Int)),\n  init: fn() -&gt;\n    Step(\n      fn() -&gt; a,\n      fn(a) -&gt;\n        Step(fn() -&gt; b, fn(b) -&gt; Step(fn() -&gt; c, fn(c) -&gt; d)),\n    ),\n) -&gt; d\n\nSynonyms:\nklubok_gleam.use_klubok3\nklubok_gleam use_klubok3","url":"klubok_gleam.html#use_klubok3"},{"doc":"klubok_gleam","title":"use_klubok4","content":"pub fn use_klubok4(\n  mock: Option(\n    #(\n      Option(fn() -&gt; a),\n      Option(fn() -&gt; b),\n      Option(fn() -&gt; c),\n      Option(fn() -&gt; d),\n    ),\n  ),\n  only: Option(Set(Int)),\n  init: fn() -&gt;\n    Step(\n      fn() -&gt; a,\n      fn(a) -&gt;\n        Step(\n          fn() -&gt; b,\n          fn(b) -&gt;\n            Step(fn() -&gt; c, fn(c) -&gt; Step(fn() -&gt; d, fn(d) -&gt; e)),\n        ),\n    ),\n) -&gt; e\n\nSynonyms:\nklubok_gleam.use_klubok4\nklubok_gleam use_klubok4","url":"klubok_gleam.html#use_klubok4"},{"doc":"klubok_gleam","title":"use_klubok5","content":"pub fn use_klubok5(\n  mock: Option(\n    #(\n      Option(fn() -&gt; a),\n      Option(fn() -&gt; b),\n      Option(fn() -&gt; c),\n      Option(fn() -&gt; d),\n      Option(fn() -&gt; e),\n    ),\n  ),\n  only: Option(Set(Int)),\n  init: fn() -&gt;\n    Step(\n      fn() -&gt; a,\n      fn(a) -&gt;\n        Step(\n          fn() -&gt; b,\n          fn(b) -&gt;\n            Step(\n              fn() -&gt; c,\n              fn(c) -&gt;\n                Step(\n                  fn() -&gt; d,\n                  fn(d) -&gt; Step(fn() -&gt; e, fn(e) -&gt; f),\n                ),\n            ),\n        ),\n    ),\n) -&gt; f\n\nSynonyms:\nklubok_gleam.use_klubok5\nklubok_gleam use_klubok5","url":"klubok_gleam.html#use_klubok5"},{"doc":"klubok_gleam","title":"use_klubok6","content":"pub fn use_klubok6(\n  mock: Option(\n    #(\n      Option(fn() -&gt; a),\n      Option(fn() -&gt; b),\n      Option(fn() -&gt; c),\n      Option(fn() -&gt; d),\n      Option(fn() -&gt; e),\n      Option(fn() -&gt; f),\n    ),\n  ),\n  only: Option(Set(Int)),\n  init: fn() -&gt;\n    Step(\n      fn() -&gt; a,\n      fn(a) -&gt;\n        Step(\n          fn() -&gt; b,\n          fn(b) -&gt;\n            Step(\n              fn() -&gt; c,\n              fn(c) -&gt;\n                Step(\n                  fn() -&gt; d,\n                  fn(d) -&gt;\n                    Step(\n                      fn() -&gt; e,\n                      fn(e) -&gt; Step(fn() -&gt; f, fn(f) -&gt; g),\n                    ),\n                ),\n            ),\n        ),\n    ),\n) -&gt; g\n\nSynonyms:\nklubok_gleam.use_klubok6\nklubok_gleam use_klubok6","url":"klubok_gleam.html#use_klubok6"},{"doc":"klubok_gleam","title":"use_klubok7","content":"pub fn use_klubok7(\n  mock: Option(\n    #(\n      Option(fn() -&gt; a),\n      Option(fn() -&gt; b),\n      Option(fn() -&gt; c),\n      Option(fn() -&gt; d),\n      Option(fn() -&gt; e),\n      Option(fn() -&gt; f),\n      Option(fn() -&gt; g),\n    ),\n  ),\n  only: Option(Set(Int)),\n  init: fn() -&gt;\n    Step(\n      fn() -&gt; a,\n      fn(a) -&gt;\n        Step(\n          fn() -&gt; b,\n          fn(b) -&gt;\n            Step(\n              fn() -&gt; c,\n              fn(c) -&gt;\n                Step(\n                  fn() -&gt; d,\n                  fn(d) -&gt;\n                    Step(\n                      fn() -&gt; e,\n                      fn(e) -&gt;\n                        Step(\n                          fn() -&gt; f,\n                          fn(f) -&gt; Step(fn() -&gt; g, fn(g) -&gt; h),\n                        ),\n                    ),\n                ),\n            ),\n        ),\n    ),\n) -&gt; h\n\nSynonyms:\nklubok_gleam.use_klubok7\nklubok_gleam use_klubok7","url":"klubok_gleam.html#use_klubok7"},{"doc":"klubok_gleam","title":"use_klubok8","content":"pub fn use_klubok8(\n  mock: Option(\n    #(\n      Option(fn() -&gt; a),\n      Option(fn() -&gt; b),\n      Option(fn() -&gt; c),\n      Option(fn() -&gt; d),\n      Option(fn() -&gt; e),\n      Option(fn() -&gt; f),\n      Option(fn() -&gt; g),\n      Option(fn() -&gt; h),\n    ),\n  ),\n  only: Option(Set(Int)),\n  init: fn() -&gt;\n    Step(\n      fn() -&gt; a,\n      fn(a) -&gt;\n        Step(\n          fn() -&gt; b,\n          fn(b) -&gt;\n            Step(\n              fn() -&gt; c,\n              fn(c) -&gt;\n                Step(\n                  fn() -&gt; d,\n                  fn(d) -&gt;\n                    Step(\n                      fn() -&gt; e,\n                      fn(e) -&gt;\n                        Step(\n                          fn() -&gt; f,\n                          fn(f) -&gt;\n                            Step(\n                              fn() -&gt; g,\n                              fn(g) -&gt;\n                                Step(fn() -&gt; h, fn(h) -&gt; i),\n                            ),\n                        ),\n                    ),\n                ),\n            ),\n        ),\n    ),\n) -&gt; i\n\nSynonyms:\nklubok_gleam.use_klubok8\nklubok_gleam use_klubok8","url":"klubok_gleam.html#use_klubok8"},{"doc":"klubok_gleam","title":"use_klubok9","content":"pub fn use_klubok9(\n  mock: Option(\n    #(\n      Option(fn() -&gt; a),\n      Option(fn() -&gt; b),\n      Option(fn() -&gt; c),\n      Option(fn() -&gt; d),\n      Option(fn() -&gt; e),\n      Option(fn() -&gt; f),\n      Option(fn() -&gt; g),\n      Option(fn() -&gt; h),\n      Option(fn() -&gt; i),\n    ),\n  ),\n  only: Option(Set(Int)),\n  init: fn() -&gt;\n    Step(\n      fn() -&gt; a,\n      fn(a) -&gt;\n        Step(\n          fn() -&gt; b,\n          fn(b) -&gt;\n            Step(\n              fn() -&gt; c,\n              fn(c) -&gt;\n                Step(\n                  fn() -&gt; d,\n                  fn(d) -&gt;\n                    Step(\n                      fn() -&gt; e,\n                      fn(e) -&gt;\n                        Step(\n                          fn() -&gt; f,\n                          fn(f) -&gt;\n                            Step(\n                              fn() -&gt; g,\n                              fn(g) -&gt;\n                                Step(\n                                  fn() -&gt; h,\n                                  fn(h) -&gt;\n                                    Step(fn() -&gt; i, fn(i) -&gt; j),\n                                ),\n                            ),\n                        ),\n                    ),\n                ),\n            ),\n        ),\n    ),\n) -&gt; j\n\nSynonyms:\nklubok_gleam.use_klubok9\nklubok_gleam use_klubok9","url":"klubok_gleam.html#use_klubok9"},{"doc":"klubok_gleam","title":"klubok_gleam","content":"","url":"klubok_gleam.html"}]);